@@ -50,7 +50,6 @@
 #include <gtk/gtkselection.h>
 #include <gtk/gtkseparatormenuitem.h>
 #include <gtk/gtksignal.h>
-#include <pango/pangoft2.h>
 #include <math.h>
 
 #include "eel-marshal.h"
@@ -1024,40 +1023,6 @@ eel_gtk_get_system_font (void)
 	return font;
 }
 
-static PangoContext *
-create_pango_ft2_context (PangoContext *base_context)
-{
-	PangoContext *context;
-			
-	context = eel_pango_ft2_get_context ();
-
-	pango_context_set_language (context, pango_context_get_language (base_context));
-	pango_context_set_base_dir (context, pango_context_get_base_dir (base_context));
-	pango_context_set_font_description (context, pango_context_get_font_description (base_context));
-
-	return context;
-}
-
-PangoContext *
-eel_gtk_widget_get_pango_ft2_context (GtkWidget *widget)
-{
-	static GQuark quark_widget_pango_ft2_context;
-	PangoContext *context;
-
-	if (quark_widget_pango_ft2_context == 0) {
-		quark_widget_pango_ft2_context = g_quark_from_static_string ("eel-ft2-context");
-	}
-  
-	context = g_object_get_qdata (G_OBJECT (widget), quark_widget_pango_ft2_context);
-	if (context == NULL) {
-		context = create_pango_ft2_context (gtk_widget_get_pango_context (widget));
-		g_object_set_qdata_full (G_OBJECT (widget), quark_widget_pango_ft2_context,
-					 context, g_object_unref);
-	}
-	
-	return context;
-}
-
 void
 eel_gtk_widget_get_button_event_location (GtkWidget *widget,
 					  const GdkEventButton *event,
