@@ -472,10 +472,11 @@ refresh_model (EelMimeApplicationChooser *chooser)
 		gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 	} else {
 		GtkTreeIter iter;
+		char *name;
 
 		gtk_tree_view_column_set_visible (column, FALSE);
 		gtk_list_store_append (chooser->details->model, &iter);
-		gchar *name = g_strdup_printf ("<i>%s</i>", _("No applications selected"));
+		name = g_strdup_printf ("<i>%s</i>", _("No applications selected"));
 		gtk_list_store_set (chooser->details->model, &iter,
 				    COLUMN_NAME, name,
 				    COLUMN_ID, NULL,
@@ -499,6 +500,7 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 {
 	char *label;
 	char *name;
+	char *emname;
 	GnomeVFSURI *vfs_uri;
 	
 	chooser->details->uri = g_strdup (uri);
@@ -540,7 +542,7 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 	}
 
 	/* first %s is filename, second %s is mime-type description */
-	gchar *emname = g_strdup_printf ("<i>%s</i>", name);
+	emname = g_strdup_printf ("<i>%s</i>", name);
 	label = g_strdup_printf (_("Select an application to open %s and others of type \"%s\""), emname, chooser->details->mime_description);
 	g_free (emname);
 	
